## More Beautiful Python

Make Python more beautiful :) This package includes syntax sugar & tools that you wish were in the standard library.

### Setup

    python -m pip install mbp
    
    > python -m mbp
    ============================== More Beautiful Python ==============================
    examples              https://github.com/user/MoreBeautifulPython/blob/main/examples.py
    execution_directory   C:\Users\user\MoreBeautifulPython
    library_path          C:\Users\user\AppData\Local\Programs\Python\Python310\lib\site-packages\mbp.py
    cpu_count             16
    version               1.2.9
    ===================================================================================


### Examples

https://github.com/sudongqi/MoreBeautifulPython/blob/main/examples.py

* Alternative for logging
* Alternative for multiprocessing
* Syntax sugar for pathlib
* Tools for file loading & handling
* Tools for summarizations
* Tools for simple statistics






